module ParserBackEnd
  require 'radius'
  include ParserCommon
  
  def parse_page_edit(page)
    if page._type == 'Page'
      layout_content = page.design.layout.content.force_encoding('UTF-8') rescue ''
      context = parser_context_edit(page)
      parser = Radius::Parser.new(context, :tag_prefix => 'r')
      parser.parse(parser.parse(layout_content))
    end
  end
  
  def parser_context_edit(page, attributes = {})
    Radius::Context.new do |c|
      c.define_tag 'snippet' do |tag|
        snippet = Snippet.first(:conditions => {:name => tag.attr['name']})
        if snippet
          snippet.content
        else
          t('nothing')
        end
      end
      c.define_tag 'language_bar' do
        @site.in_use_locales.map{ |locale|
          lang = I18nVariable.first(:conditions => {:key => locale})[locale]
          if I18n.locale.to_s.eql?(locale)
            lang
          else
            "<a href='?locale=#{locale}'>#{lang}</a>"
          end
        }.join(' | ')
      end
      c.define_tag 'multi_lang' do |tag|
        tag.expand
      end
      c.define_tag 'multi_lang:lang' do |tag|
        tag.expand if tag.attr['name'].eql?(I18n.locale.to_s)
      end
      c.define_tag 'css' do |tag|
        assets = Asset.any_in(:filename => tag.attr['name'].split(',').map(&:strip))
        res = ''
        assets.each do |asset|
          res << "<link href='#{asset.data.file.url}' rel='stylesheet' type='text/css' /> " if asset.data.file.content_type.eql?('text/css')
        end
        res
      end
      c.define_tag 'image' do |tag|
        image = page.custom_images.detect{|image| image.name.eql?(tag.attr['name']) }
        image = page.design.custom_images.detect{|image| image.name.eql?(tag.attr['name']) } unless image
        image = page.design.images.detect{|image| image.name.eql?(tag.attr['name']) } unless image
        if image
          res = "<img src=#{image.file.url} "
          tag.attr.each do |l|
            res << "#{l[0]}='#{l[1]}' "
          end
          res << '>'
        end
      end
      c.define_tag 'stylesheets' do |tag|
        res = ''
        res << "<link href='#{page.design.reset_css.file.url}' rel='stylesheet' type='text/css' />" if page.design.reset_css
        res << "<link href='#{page.design.default_css.file.url}' rel='stylesheet' type='text/css' />" if page.design.default_css
        theme = page.design.themes.detect{ |d| d.id == page.theme_id  }
        res << "<link href='#{theme.file.url}' rel='stylesheet' type='text/css' />" if theme
        res
      end
      c.define_tag 'javascripts' do |tag|
        res = ''
        res << "<script type='text/javascript' src='/static/jquery.js'></script>"
        res << "<script type='text/javascript' src='/static/kernel.js'></script>"
        page.design.javascripts.each do |js|
          res << "<script type='text/javascript' src='#{js.file.url}'></script>"
        end
        res
      end
      c.define_tag 'adbanner' do |tag|
        ret = ''
        ad_banner = AdBanner.first(conditions:{title: tag.attr["name"]})
        ret << "<script type='text/javascript' src='http://cloud.github.com/downloads/malsup/cycle/jquery.cycle.all.latest.js'></script>"
        ret << "<script type='text/javascript'> $(document).ready(function() { $('.slideshow').cycle({ fx: '#{ad_banner.ad_fx.nil?? 'fade': ad_banner.ad_fx}' }); }); </script>"
       
        ret << "<div id='#{tag.attr['name']}' ad_banner_id='#{ad_banner.id}' class='editable' style='border:solid 1px; margin:5px; padding:5px;'>"
        ret << "<div class='edit_link' style='display:none'>"
        ret << " <a href='#{edit_admin_ad_banner_path(ad_banner.id)}' class='nav'>#{t(:edit)}</a>"
        ret << '</div>'
       #==================================
        ret << "<div class='slideshow'>"
         ad_banner.ad_images.each do |ad_image|
           ret << "<img src='#{ad_image.file}' />"
          end
        ret << "</div>"
      #==================================
      ret << "</div>"
      end
      c.define_tag 'layout_part' do |tag|
        part = page.page_parts.detect{ |p| p.name.to_s == tag.attr['name'].to_s }
        ret = ''
        ret << "<div id='#{tag.attr['name']}' part_id='#{part.id}'>"
        ret << tag.expand
        ret << '</div>'
      end
      c.define_tag 'content' do |tag|
        ret = ''
        if (tag.attributes["main"] == "true" && !page.module_app.nil?)
          ret << "<div id='appfrontend' class='dymanic_load' path='/panel/#{page.module_app.title}/front_end/#{page.app_frontend_url}?inner=true'></div>"
        else
           part = page.page_parts.detect{ |p| p.name.to_s == tag.attr['name'].to_s }
            ret << "<div id='#{tag.attr['name']}' part_id='#{part.id}' class='editable' style='border:solid 1px; margin:5px; padding:5px;'>"
            ret << "<div class='edit_link' style='display:none'>"
            ret << " <a href='#{edit_admin_page_part_path(part.id)}' class='nav'>#{t(:edit)}</a>"
            ret << '</div>'
            ret << part.i18n_variable[I18n.locale.to_s] rescue ''
            ret << '</div>'
        end
      end
      c.define_tag 'link' do |tag|
        item = Item.first(:conditions => { :full_name => tag.attr['name'] })
        ret = ''
        ret << "<a href='"
        ret << eval("admin_#{item._type.downcase}_path(item.id)")
        ret << "' class='nav'>"
        ret << item.i18n_variable[I18n.locale]
        ret << "</a>"
      end
      c.define_tag 'menu' do |tag|
        home = get_homepage
        menu = page.design.layout.menu
        menu_level(home, 0, menu, true)
      end
    end
  end
  
  def self.included(base)
    base.send :helper_method, :parse_page_edit if base.respond_to? :helper_method
  end

end
