module ParserFrontEnd
  require 'radius'
  include ParserCommon

  def parser_context(page, attributes = {}, id = nil)
    Radius::Context.new do |c|
      c.define_tag 'snippet' do |tag|
        snippet = Snippet.first(:conditions => {:name => tag.attr['name']})
        if snippet
          snippet.content
        else
          t('nothing')
        end
      end
      c.define_tag 'language_bar' do
        @site.in_use_locales.map{ |locale|
          lang = I18nVariable.first(:conditions => {:key => locale})[locale]
          if I18n.locale.to_s.eql?(locale)
            lang
          else
            "<a href='?locale=#{locale}'>#{lang}</a>"
          end
        }.join(' | ')
      end
      c.define_tag 'locale' do |tag|
        case attributes[:locale]
          when 'create'
            var = I18nVariable.new(:key => (tag.attr['name'] rescue nil), :document_class => 'Text')
            @site.valid_locales.each do |locale|
              var[locale] = tag.attr[locale] rescue nil
            end
            var.save!
            res = ''
            res << "<r:locale id='#{var.id}' " 
            res << "name='#{var.key}' " if var.key
            @site.valid_locales.each do |locale|
              res << "#{locale}='#{var[locale]}' "
            end
            res << '/>'
          when 'show'
            var = I18nVariable.find(tag.attr['id'])
            res = ''
            res << "<r:locale " 
            res << "name='#{var.key}' " if var.key
            @site.valid_locales.each do |locale|
              res << "#{locale}='#{var[locale]}' "
            end
            res << '/>'
          when 'destroy'
            var = I18nVariable.find(tag.attr['id'])
            var.destroy
        end
      end
      c.define_tag 'multi_lang' do |tag|
        tag.expand
      end
      c.define_tag 'multi_lang:lang' do |tag|
        tag.expand if tag.attr['name'].eql?(I18n.locale.to_s)
      end
      c.define_tag 'css' do |tag|
        assets = Asset.any_in(:filename => tag.attr['name'].split(',').map(&:strip))
        res = ''
        assets.each do |asset|
          res << "<link href='#{asset.data.file.url}' rel='stylesheet' type='text/css' /> " if asset.data.file.content_type.eql?('text/css')
        end
        res
      end
      c.define_tag 'stylesheets' do |tag|
        res = ''
        res << "<link href='#{page.design.reset_css.file.url}' rel='stylesheet' type='text/css' />" if page.design.reset_css
        res << "<link href='#{page.design.default_css.file.url}' rel='stylesheet' type='text/css' /> " if page.design.default_css
        theme = page.design.themes.detect{ |d| d.id == page.theme_id  }
        res << "<link href='#{theme.file.url}' rel='stylesheet' type='text/css' />" if theme
        res
      end
      c.define_tag 'javascripts' do |tag|
        res = ''
        res << "<script type='text/javascript' src='/static/jquery.js'></script>"
        res << "<script type='text/javascript' src='/static/kernel.js'></script>"
        page.design.javascripts.each do |js|
          res << "<script type='text/javascript' src='#{js.file.url}'></script>"
        end
        res
      end
      c.define_tag 'adbanner' do |tag|
        res = ''
        ad_banner = AdBanner.first(conditions:{title: tag.attr["name"]})
        if ad_banner.display?
          res << "<script type='text/javascript' src='http://cloud.github.com/downloads/malsup/cycle/jquery.cycle.all.latest.js'></script>"
          res << "<script type='text/javascript'>function onAfter(e) { 
              var parent = $(this).parent();
              var time_to_next = $(this).attr('time_to_next');
              parent.cycle('pause');
              setTimeout(function(){parent.cycle('resume')},time_to_next);

          } $(document).ready(function() { $('.slideshow').cycle({after:   onAfter,timeout:1 ,fx: '#{ad_banner.ad_fx.nil?? 'fade': ad_banner.ad_fx}' }).children('img').click(function(){if($(this).attr('link_open')=='new_window'){window.open($(this).attr('link_url'));} else{document.location.href=$(this).attr('link_url');}});; }); </script>"

          res << "<div class='slideshow'>"
           ad_banner.ad_images.each do |ad_image|
             res << "<img src='#{ad_image.file}' "
             res << "alt='#{ad_image.picture_intro || ' '}' "
             res << "time_to_next='#{ad_image.get_delay_time}' "
             res << "link_open='#{ad_image.link_open}' "
             res << "link_url='#{(ad_banner.direct_to_after_click?? ad_image.out_link : ad_banner.context) || ' '}' "
             res << "/>"
            end
          res << "</div>"
        end
        res
      end
      c.define_tag 'image' do |tag|
        image = page.custom_images.detect{|image| image.name.eql?(tag.attr['name']) }
        image = page.design.custom_images.detect{|image| image.name.eql?(tag.attr['name']) } unless image
        image = page.design.images.detect{|image| image.name.eql?(tag.attr['name']) } unless image
        if image
          res = "<img src=#{image.file.url} "
          tag.attr.each do |l|
            res << "#{l[0]}='#{l[1]}' "
          end
          res << '>'
        end
      end
      c.define_tag 'layout_part' do |tag|
        part = page.page_parts.detect{ |p| p.name.to_s == tag.attr['name'].to_s } rescue nil
        part.content
      end
      c.define_tag 'content' do |tag|
        ret = ''
        if (tag.attributes["main"] == "true" && !page.module_app.nil?)
          ret << "<div id='appfrontend' class='dymanic_load' path='/panel/#{page.module_app.title}/front_end/#{page.app_frontend_url}"
          ret << "/#{id}" if id
          ret << "?inner=true'></div>"
        else
          part = page.page_parts.detect{ |p| p.name.to_s == tag.attr['name'].to_s } rescue nil
          ret << part.content rescue nil
        end
        ret
      end
      c.define_tag 'link' do |tag|
        item = Item.first(:conditions => { :full_name => tag.attr['name'] })
        ret = ''
        ret << "<a href='#{tag.attr['name']}'>"
        ret << item.i18n_variable[I18n.locale]
        ret << '</a>'
      end
      c.define_tag 'menu' do |tag|
        home = get_homepage
        menu = page.design.layout.menu
        menu_level(home, 0, menu)
      end
    end
  end
  
  def parse_page(page, id = nil)
    if page._type == 'Page'
      layout_content = page.design.layout.content.force_encoding('UTF-8') rescue ''
      context = parser_context(page, {}, id)
      parser = Radius::Parser.new(context, :tag_prefix => 'r')
      parser.parse(parser.parse(layout_content))
    end
  end
  
  def self.included(base)
    base.send :helper_method, :parse_page if base.respond_to? :helper_method
  end
  
end
